# Oh My Bash and `.bashrc file` 

Next, to make easier work with the bash system let us install the oh-my-bash tool:

```
$ bash -c "$(curl -fsSL https://raw.githubusercontent.com/ohmybash/oh-my-bash/master/tools/install.sh)"
```

- make an alias 
- export `export PATH="/home/username/anaconda/bin:$PATH"` or `PATH="/home/username/anaconda/bin:$PATH"`
- `ln -s``

# Install Vim Plugin manager
First we need to install the Vim plugin manager to easily add and remove packages into vim editor. Thus, let us add the `plugin.vim`:

```
curl -fLo ~/.vim/autoload/plug.vim --create-dirs \
    https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim
```

## Usage
Add a vim-plug section to your `~/.vimrc` file:
1. Begin the section with call plug#begin([PLUGIN_DIR])
2. List the plugins with `Plug` commands
3. call `plug#end()` to update `&runtimepath` and initialize plugin system
	* Automatically executes `filetype plugin indent on and syntax enable`. You can revert the settings after the call. e.g. `filetype indent off`, `syntax off`, etc.

## Example

```
call plug#begin()
" The default plugin directory will be as follows:
"   - Vim (Linux/macOS): '~/.vim/plugged'
"   - Vim (Windows): '~/vimfiles/plugged'
"   - Neovim (Linux/macOS/Windows): stdpath('data') . '/plugged'
" You can specify a custom plugin directory by passing it as the argument
"   - e.g. `call plug#begin('~/.vim/plugged')`
"   - Avoid using standard Vim directory names like 'plugin'

" Make sure you use single quotes

" Any valid git URL is allowed
Plug 'https://github.com/junegunn/vim-github-dashboard.git'


" On-demand loading
Plug 'scrooloose/nerdtree', { 'on':  'NERDTreeToggle' }

" Initialize plugin system
call plug#end()
```

For a better understanding on how to use the Vim Plugin manager visit the [git webpage](https://github.com/junegunn/vim-plug).

# The `.vimrc` file

Next you will see the contents of the `vimrc` file in this repository:
```
" ------------------
"         __                     
" .--.--.|__|.--------.----.----.
" |  |  ||  ||        |   _|  __|
"  \___/ |__||__|__|__|__| |____|
" ------------------
"
" Basic settings 
" --------------
set nocompatible
filetype plugin indent on
syntax enable

set number relativenumber
set path+=**
set wildmode=longest,list,full
set encoding=UTF-8
set cursorline
set showmatch   " matching brackets
set linebreak
set ignorecase  " case insensitive matching
set smartcase   " smart case matching
"set clipboard+=unnamedplus
set mouse=a
set tabstop=4
set shiftwidth=4
set softtabstop=4
set spelllang=en_us
set showtabline=2
set laststatus=2
set backspace=indent,eol,start  " more powerful backspacing
" ------------------
" Basic styling
" ------------------
highlight Comment cterm=italic
highlight CursorLine ctermbg=Black cterm=NONE
highlight CursorLineNr ctermbg=Black cterm=bold ctermfg=Green
highlight LineNr ctermbg=Black ctermfg=White 
" ------------------
" Plugin settings
" ------------------
call plug#begin()
	Plug 'sonph/onehalf', { 'rtp': 'vim' }
	Plug 'vim-airline/vim-airline'
    Plug 'vim-airline/vim-airline-themes'
	Plug 'preservim/nerdtree'
    Plug 'preservim/vim-markdown'
call plug#end()

" Theme configuration
" ------------------
colorscheme onehalfdark "archery
let g:airline_theme = 'onehalfdark' "'archery'
set t_Co=256
let g:airline_powerline_fonts=1
let g:airline#extensions#tabline#left_sep = ' '
let g:airline#extensions#tabline#left_alt_sep = '|'
let g:airline_symbols = {}
let g:airline_symbols.colnr = ' ㏇:'
```
after copy and paste, or added the require code call the plug installer by entering on command mode in Vim (pressing `Esc` key), then, call `:PlugInstall` to update and install the new Plugins.


